#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from pyams_i18n.schema import I18nTextLineField


__docformat__ = 'restructuredtext'

from zope.contentprovider.interfaces import IContentProvider
from zope.interface import Interface, Attribute
from zope.schema import Bool

from pyams_default_theme import _


class ISearchResultTitle(Interface):
    """Search result title interface"""


class ISearchResultHeader(Interface):
    """Search result header interface"""


class ISearchResultTarget(Interface):
    """Search result target URL interface"""


class ISearchResultRenderer(IContentProvider):
    """Search result renderer interface"""

    url = Attribute("Search result URL")
    title = Attribute("Search result title")
    header = Attribute("Search result header")


class ISearchResultsPortletRendererBaseSettings(Interface):
    """Search results portlet renderer base settings interface"""

    display_results_count = Bool(title=_("Display results count?"),
                                 description=_("If 'no', results count will not be displayed"),
                                 required=True,
                                 default=True)

    allow_sorting = Bool(title=_("Allow results sorting?"),
                         description=_("If 'no', results will not be sortable"),
                         required=True,
                         default=True)

    allow_pagination = Bool(title=_("Allow pagination?"),
                            description=_("If 'no', results will not be paginated"),
                            required=True,
                            default=True)


class ISearchResultsPortletDefaultRendererSettings(ISearchResultsPortletRendererBaseSettings):
    """Search results portlet default renderer settings interface"""


class ISearchResultsPortletPanelsRendererSettings(ISearchResultsPortletRendererBaseSettings):
    """Search results portlet panels renderer settings interface"""

    button_title = I18nTextLineField(title=_("Button's title"),
                                     description=_("Navigation button's title is normally defined "
                                                   "based on target's content type; you can "
                                                   "override this label by giving a custom title "
                                                   "here"),
                                     required=False)
